﻿using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace P6_2
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        Texture2D texture;
        //Количество кадров в изображении
        const int frames = 2;
        //Частота анимации - кадров в секунду
        const int framesPerSec =10;
        //Текущий кадр для вывода на экран
        int numberOfFrame=0;
        //Время, в течение которого отображается один кадр
        float timePerFrame;
        //Время, которое прошло с начала отображения текущего кадра
        float totalElapsed;
        //Позиция вывода спрайта
        Vector2 position;
        //Прямоугольник для задания позиции кадра в изображении
        Rectangle sprRec;
        //Ширина кадра
        int widthFrame = 64;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            position = new Vector2(100, 100);
            //Время для одного кадра вычисляется как результат деления 1 секунды
            //на заданное количество кадров в секунду
            timePerFrame = (float)1 / framesPerSec;
            sprRec = new Rectangle(0, 0, 64, 64);

            base.Initialize();
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);
            texture = Content.Load<Texture2D>("animation");

            // TODO: use this.Content to load your game content here
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }
        //Эта процедура используется для анимации спрайта
        //Она принимает количество секунд, прошедших с предыдущего вызова
        //процедуры Update
        void ChangeFrame(float elpT)
        {
            //Увеличим общее время отображения спрайта на
            //время, прошедшее с последнего вызова процедуры
            totalElapsed += elpT;
            //если общее время отображения спрайта больше времени,
            //выделенного на один спрайт
                if (totalElapsed > timePerFrame)
                {
                    //Если номер кадра равен количеству кадров-1
                    if (numberOfFrame == frames-1)
                    {
                        //установим номер кадра в 0
                        numberOfFrame = 0;
                    }
                        //иначе увеличим номер кадра на 1
                    else numberOfFrame++;
                    //создадим новый прямоугольник
                    //Его координата X соответствует координате левого верхнего угла
                    //кадра, Y равно 0, длина и ширина всегда равны 64
                    sprRec = new Rectangle((int)widthFrame * numberOfFrame, 0, 64, 64);
                    //сбросим totalElapsed в 0
                    totalElapsed = 0;
                }
         
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            //Вызов процедуры анимации спрайта
            //в качестве параметра передается время,прошедшее после
            //последнего вызова Update
            ChangeFrame((float)gameTime.ElapsedGameTime.TotalSeconds);
            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            graphics.GraphicsDevice.Clear(Color.CornflowerBlue);
            spriteBatch.Begin();
            spriteBatch.Draw(texture, position, sprRec, Color.White);
            spriteBatch.End();
            base.Draw(gameTime);
        }
    }
}
